@@ -12,10 +12,18 @@ class ControlSize(object):
     Small = const.NSSmallControlSize
     Mini = const.NSMiniControlSize
 
+class TextAlignment(object):
+    Left = const.NSLeftTextAlignment
+    Right = const.NSRightTextAlignment
+    Center = const.NSCenterTextAlignment
+    Justified = const.NSJustifiedTextAlignment
+    Natural = const.NSNaturalTextAlignment
+    
 class Control(View):
     CONTROL_HEIGHTS = ControlHeights(20, 17, 14)
     PROPERTIES = View.PROPERTIES + [
         ActionProperty('action'), 'font', Property('controlSize', 'cell.controlSize'), 'formatter',
+        'alignment'
     ]
     
     def __init__(self, parent, width, height):
@@ -25,7 +33,7 @@ class Control(View):
         self.action = None
         self.formatter = None
     
-    def hasFixedHeight(self):
+    def _hasFixedHeight(self):
         return True
     
     def _getControlHeights(self):
@@ -48,9 +56,9 @@ class Control(View):
         if controlSize == ControlSize.Mini:
             self.height = controlHeights.mini
         elif controlSize == ControlSize.Small:
-            self.height = self.CONTROL_HEIGHTS.small
+            self.height = controlHeights.small
         else:
-            self.height = self.CONTROL_HEIGHTS.regular
+            self.height = controlHeights.regular
         self.font.size = self._getControlFontSize(controlSize)
         self._updateLayoutDeltas()
     
